/*
 * versionNumber.h
 * ---------------
 * Purpose: OpenMPT version number.
 * Notes  : (currently none)
 * Authors: OpenMPT Devs
 * The OpenMPT source code is released under the BSD license. Read LICENSE for more details.
 */


#pragma once

#include "openmpt/all/BuildSettings.hpp"

OPENMPT_NAMESPACE_BEGIN

// Version definitions. The only thing that needs to be changed when changing version number.
#define VER_MAJORMAJOR  1
#define VER_MAJOR      31
#define VER_MINOR      01
#define VER_MINORMINOR 00

OPENMPT_NAMESPACE_END
